@@ -3,8 +3,11 @@
  *
  *  Created by Wei Sun on Aug 15 2007.
  *
+ *  Last updated by Wei Sun on Nov 18 2009.
  */
-
+#include <R_ext/Lapack.h>
+#include <R_ext/Applic.h>
+#include <R_ext/PrtUtil.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <math.h>
